Learn R Programming

wbwdi (version 1.0.3)

wdi_get_regions: Download regions from the World Bank API

Description

This function returns a tibble of supported regions for querying the World Bank API.The regions include various geographic areas covered by the World Bank's datasets.

Usage

wdi_get_regions(language = "en")

Value

A tibble with the following columns:

region_id

An integer identifier for each region.

region_code

A character string representing the region code.

region_iso2code

A character string representing the ISO2 code for the region.

region_name

A character string representing the name of the region, in the specified language.

Arguments

language

A character string specifying the language code for the API response (default is "en" for English).

Details

This function provides a reference for the supported regions, which are important for refining queries related to geographic data in the World Bank's datasets. The region_id column is unique for seven key regions.

Examples

Run this code
# Download all regions
wdi_get_regions()

Run the code above in your browser using DataLab