Learn R Programming

wbwdi (version 1.0.3)

wdi_get_languages: Download languages from the World Bank API

Description

This function returns a tibble of supported languages for querying the World Bank API. The supported languages include English, Spanish, French, Arabic, and Chinese, etc.

Usage

wdi_get_languages()

Arguments

Value

A tibble with three columns:

language_code

A character string representing the language code (e.g., "en" for English).

language_name

A character string representing the description of the language (e.g., "English").

native_form

A character string representing the native form of the language (e.g., "English").

Details

This function provides a simple reference for the supported languages when querying the World Bank API.

Examples

Run this code
# Download all languages
wdi_get_languages()

Run the code above in your browser using DataLab