Learn R Programming

wbwdi (version 1.0.3)

wdi_get_topics: Download topics from the World Bank API

Description

This function returns a tibble of supported topics for querying the World Bank API. Topics represent the broad subject areas covered by the World Bank's datasets.

Usage

wdi_get_topics(language = "en")

Value

A tibble with three columns:

id

The unique identifier for the topic.

value

The name of the topic (e.g., "Education", "Health").

source_note

A brief description or note about the topic.

Arguments

language

A character string specifying the language code for the API response (default is "en" for English).

Details

This function provides a reference for the supported topics that can be used to refine your queries when accessing the World Bank API. Topics represent different areas of focus for data analysis.

Examples

Run this code
# Download all available topics in English
wdi_get_topics()

Run the code above in your browser using DataLab